#
# spec file for package eog
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           eog
Version:        41.2
Release:        150400.3.3.2
Summary:        Image Viewer for GNOME
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          Productivity/Graphics/Viewers
URL:            https://wiki.gnome.org/Apps/EyeOfGnome
Source0:        https://download.gnome.org/sources/eog/41/%{name}-%{version}.tar.xz

BuildRequires:  fdupes
BuildRequires:  gtk-doc
BuildRequires:  libjpeg-devel
BuildRequires:  meson >= 0.44.0
BuildRequires:  pkgconfig
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(exempi-2.0) >= 1.99.5
BuildRequires:  pkgconfig(gdk-pixbuf-2.0) >= 2.36.5
BuildRequires:  pkgconfig(gio-2.0) >= 2.53.4
BuildRequires:  pkgconfig(gio-unix-2.0) >= 2.53.4
BuildRequires:  pkgconfig(glib-2.0) >= 2.53.4
BuildRequires:  pkgconfig(gnome-desktop-3.0) >= 2.91.2
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gsettings-desktop-schemas) >= 2.91.92
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.22.0
BuildRequires:  pkgconfig(gtk+-unix-print-3.0) >= 3.5.4
BuildRequires:  pkgconfig(lcms2)
BuildRequires:  pkgconfig(libexif)
BuildRequires:  pkgconfig(libpeas-1.0) >= 0.7.4
BuildRequires:  pkgconfig(libpeas-gtk-1.0) >= 0.7.4
BuildRequires:  pkgconfig(libportal) >= 0.3
BuildRequires:  pkgconfig(librsvg-2.0) >= 2.44.0
BuildRequires:  pkgconfig(shared-mime-info) >= 0.20

%description
Eye of GNOME (eog) is a simple graphics viewer for the GNOME desktop
which uses the gdk-pixbuf library. It can deal with large images, and
zoom and scroll with constant memory usage.

%package devel
Summary:        Development files for eog, an image viewer
Group:          Development/Libraries/GNOME
Requires:       %{name} = %{version}

%description devel
Eye of GNOME (eog) is a simple graphics viewer for the GNOME desktop
which uses the gdk-pixbuf library.

This subpackage contains all the necessary files and documentation for
developing eog plugins.

%lang_package

%prep
%autosetup -p1

%build
%meson \
	-D libexif=true \
	-D cms=true \
	-D xmp=true \
	-D libjpeg=true \
	-D librsvg=true \
	-D gtk_doc=true \
	-D introspection=true \
	-D installed_tests=false \
	%{nil}
%meson_build

%install
%meson_install
%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}%{_datadir}

%files
%license COPYING
%doc NEWS
%doc %{_datadir}/help/C/%{name}/
%{_bindir}/%{name}
%{_libdir}/%{name}/
%{_datadir}/applications/org.gnome.eog.desktop
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/%{name}.appdata.xml
%{_datadir}/icons/hicolor/*/apps/org.gnome.%{name}*.svg
%{_datadir}/%{name}/
%{_datadir}/GConf/gsettings/%{name}.convert
%{_datadir}/glib-2.0/schemas/org.gnome.%{name}.enums.xml
%{_datadir}/glib-2.0/schemas/org.gnome.%{name}.gschema.xml
# %%{_datadir}/eog/gir-1.0/ goes to the -devel package.
%exclude %{_datadir}/%{name}/gir-1.0/

%files devel
%doc AUTHORS ChangeLog HACKING MAINTAINERS TODO
%doc %{_datadir}/gtk-doc/html/%{name}/
%{_includedir}/%{name}-3.0/
%{_libdir}/pkgconfig/%{name}.pc
%{_datadir}/%{name}/gir-1.0/

%files lang -f %{name}.lang

%changelog
* Sun Mar 20 2022 bjorn.lie@gmail.com
- Update to version 41.2:
  + eog-window: use correct type for display_profile.
  + Fix discovery of Evince for multi-page images.
  + Updated translations.
* Sat Dec  4 2021 bjorn.lie@gmail.com
- Update to version 41.1:
  + Bugs fixed:
  - Accessibility: add proper mnemonic relations and labelling
  - Remove incorrect arg for i18n.merge_file
  - Saving image fails with GVFS SFTP backend
  + Updated translations.
* Sun Sep 19 2021 bjorn.lie@gmail.com
- Update to version 41.0:
  + Updated translations.
* Thu Sep 16 2021 sbrabec@suse.com
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Sat Sep  4 2021 bjorn.lie@gmail.com
- Update to version 41.rc:
  + Updated translations.
* Mon Aug 23 2021 dimstar@opensuse.org
- Update to version 41.beta:
  + Fix deprecated functions.
  + Updated translations.
* Sun Aug 15 2021 bjorn.lie@gmail.com
- Update to version 40.3:
  + EogImage: Do not crash if content type or filesize cannot be
    detected.
  + Updated translations.
* Sun Jun  6 2021 bjorn.lie@gmail.com
- Update to version 40.2:
  + reload: Remove unused GtkActionGroup member
  + Critical warning after closing EOG (invalid unclassed pointer;
    assertion 'EOG_IS_IMAGE (img)' failed)
  + Updated translations.
* Mon May  3 2021 dimstar@opensuse.org
- Update to version 40.1:
  + Fix warnings when dragging or receiving inputs on empty view.
  + Remove directories when unmount external drive.
  + Crash Report: eog_thumb_view_clear_range: assertion failed:
    (start_thumb <= end_thumb).
  + Updated translations.
* Sun Mar 21 2021 dimstar@opensuse.org
- Update to version 40.0:
  + Updated translations.
* Thu Mar 18 2021 dimstar@opensuse.org
- Update to version 40.rc:
  + docs: Remove shortcuts page.
  + docs: Update EOG icon.
  + docs: Update some outdated information.
  + help: Preferences do not have a close button.
  + help: Fix a sentence suggesting click on
    "Show other application".
  + Part of a large image (exceeding certain dimensions) does not
    display.
  + docs: Remove PicasaWeb support.
  + Updated translations.
* Mon Feb 15 2021 gmbr3@opensuse.org
- Update to version 40.beta:
  + Re-detect mimetype from data if loading fails the first time.
  + Update EogWindow and EogListStore when deleting a monitored
    directory.
  + Warning about overwriting GError when unlinking a directory
    while viewing.
  + Update appdata screenshot.
* Mon Feb 15 2021 dimstar@opensuse.org
- Update to version 40.alpha:
  + build: Centralize path absolutization.
* Sun Feb 14 2021 bjorn.lie@gmail.com
- Update to version 3.38.2:
  + Warning about overwriting GError when unlinking a directory
    while viewing.
  + Update appdata screenshot.
  + Updated translations.
* Sat Nov 21 2020 bjorn.lie@gmail.com
- Update to version 3.38.1:
  + Bugs fixed: glgo#GNOME/eog!77, glgo#GNOME/eog!81,
    glgo#GNOME/eog#154.
  + Updated translations.
* Mon Sep 14 2020 dimstar@opensuse.org
- Update to version 3.38.0:
  + Updated translations.
* Sat Sep  5 2020 dimstar@opensuse.org
- Update to version 3.37.92:
  + Updated translations.
* Fri Sep  4 2020 dimstar@opensuse.org
- Update to version 3.37.90:
  + build: Make libportal dependency optional.
  + help: change file to File.
  + eog-window: Use view-restore symbolic icon.
  + Make pressing Ctrl+Q close all windows.
  + Use Wallpaper Portal for "Set as Wallpaper" when possible.
  + Should inhibit screensaver only in slideshow mode.
- Changes from version 3.37.2:
  + Made strings consistent in format-change.page.
  + Make EoG usable on phones.
  + Use Portals and GtkAppChooserDialog for the "Open With"
    choices.
  + String with zooming in and out might be incorrect.
- Changes from version 3.37.1:
  + Change "Back space" to "Backspace".
  + Change "Slide show" to "Slideshow".
  + "Use the keyboard keys" could explain which ones.
  + Updated translations.
- Add pkgconfig(libportal) BuildRequires: new (optional)
  dependency.
* Sat Jul  4 2020 bjorn.lie@gmail.com
- Update to version 3.36.3:
  + Bug fixes:
  - EogThumbView: Fix visible range callback being queued to
    often.
  - EogJobs: Ensure thumbnail job emits finished signal even if
    failed.
  + Updated translations.
* Sat Apr 25 2020 bjorn.lie@gmail.com
- Update to version 3.36.2:
  + Bugs fixed:
  - help-overlay: Fix next/previous image shortcuts for RTL
    languages.
  - appdata: Update to release 3.36.1.
  - eog-application.c: Add new shortcut for zoom-normal action.
  - Swipe left and swipe right action have the same description
    in Keyboard Shortcuts dialog.
  - eog 3.36 cannot open HEIF files via gdk-pixbuf loader.
  + Updated translations.
* Sat Mar 28 2020 bjorn.lie@gmail.com
- Update to version 3.36.1:
  + Updated translations.
* Sun Mar  8 2020 bjorn.lie@gmail.com
- Update to version 3.36.0:
  + Corrected link to bug writing guide in help docs.
  + Bugs fixed: Fix missing removable storage support in snap
    package.
  + Updated translations.
* Sat Feb 29 2020 bjorn.lie@gmail.com
- Update to version 3.35.92:
  + Updated translations.
* Tue Feb 18 2020 dimstar@opensuse.org
- Update to version 3.35.91:
  + Updated translations.
* Wed Feb 12 2020 dimstar@opensuse.org
- Update to version 3.35.3:
  + EogPrintImageSetup: Rework spinbutton behaviour.
  + Improve Keyboard Shortcuts.
  + Remove outdated info from HACKING.
  + App icon: minor updates for 3.36.
  + help: Add Danish screenshots.
- Changes from version 3.35.2:
  + Various EogThumbView bugfixes.
  + Unfullscreen using F11 doesn't work if window is empty.
- Changes from version 3.35.1:
  + Use librsvg's GInputStream functions.
  + Various EogThumbView bugfixes.
  + Zoom with mouse wheel is really slow.
  + Updated translations.
* Sat Jan 25 2020 dimstar@opensuse.org
- No longer recommend -lang: supplements are in use
* Sun Jan  5 2020 bjorn.lie@gmail.com
- Update to version 3.34.2:
  + Bug fixes: Pan gesture in RTL shows always next picture.
  + Updated translations.
* Mon Oct  7 2019 bjorn.lie@gmail.com
- Update to version 3.34.1:
  + Bug fixes:
  - Check errors after rsvg_handle_close().
  - icon: create a nightly app icon.
  - EogApplication: Initialize debug before plugin engine
  + Updated translations.
* Wed Sep 11 2019 bjorn.lie@gmail.com
- Update to version 3.34.0:
  + Updated translations.
* Thu Aug 29 2019 bjorn.lie@gmail.com
- Update to version 3.33.91:
  + Updated translations.
- Changes from version 3.33.90:
  + Updated translations.
- Changes from version 3.33.3:
  + Improve meson port.
  + build: Use #ifdef consistently.
  + Updated translations.
* Tue Jun 25 2019 bjorn.lie@gmail.com
- Update to version 3.33.2:
  + Bug fixes: Unreasonable limitation of scaling in print dialog.
  + Updated translations.
- Changes from version 3.33.1:
  + Various help doc improvements.
  + Bug fixes: glgo#GNOME/eog!20.
* Wed May 22 2019 bjorn.lie@gmail.com
- Update to version 3.32.2:
  + Fix PNG file displayed darker after conversion from JPEG file.
  + Only build and attach RGB color profiles to PNGs when both gAMA
    and cHRM are present.
  + Updated translations.
* Tue Apr  9 2019 bjorn.lie@gmail.com
- Update to version 3.32.1:
  + Even more updated help docs.
  + Bugs fixed: glgo#GNOME/eog#50 SIGSEGV in g_mutex_lock().
  + Updated translations.
* Mon Mar 11 2019 bjorn.lie@gmail.com
- Update to version 3.32.0:
  + Updated translations.
* Tue Mar  5 2019 bjorn.lie@gmail.com
- Update to version 3.31.91:
  + Improved help docs.
  + Bugs fixed: Remove uta.[ch] and the old drawing code.
  + Updated translations.
* Fri Feb 15 2019 bjorn.lie@gmail.com
- Update to version 3.31.90:
  + Improved wording in help docs.
  + Bugs fixed: EogScrollView: Set scale=1 for the image surface.
  + Updated translations.
* Tue Jan  8 2019 bjorn.lie@gmail.com
- Update to version 3.31.3:
  + Updated translations.
* Sat Dec 29 2018 bjorn.lie@gmail.com
- Update to version 3.31.2:
  + Improved primary menu.
  + Improved app icon.
  + Bug fixes: Add View submenu.
  + Updated translations.
- Changes from version 3.31.1:
  + Update app icon.
  + Remove appmenu.
  + Bug fixes:
  - Add Flatpak manifest.
  - icon: update app icon.
  - Remove appmenu.
  - Fix warnings.
  - README is obsolete.
  - Slideshow accidentally skips images when using a slow device
    for file access.
  - Use 96dpi when displaying SVGs.
  + Updated translations.
* Wed Sep 26 2018 bjorn.lie@gmail.com
- Update to version 3.28.4:
  + Bugs fixed: glgo#GNOME/eog!4, glgo#GNOME/eog!5,
    glgo#GNOME/eog!6, glgo#GNOME/eog#6, glgo#GNOME/eog#8,
    glgo#GNOME/eog#10.
  + Updated translations.
* Mon Jul 23 2018 bjorn.lie@gmail.com
- Update to version 3.28.3:
  + Add OARS and update gitlab URLs.
  + Add icns to mime types.
  + Fix memory leak when viewing many jpeg images.
  + build: it's enable_xmp not enable_exempi.
  + Updated translations.
* Mon Jul 23 2018 dimstar@opensuse.org
- Help translation-update-upstream finding the right gettext domain
  name: pass "po %%{name}" to the call.
* Mon May  7 2018 luc14n0@linuxmail.org
- Update to version 3.28.2:
  + Updated translations.
- Update devel package description to be more inclusive about its
  contents.
- Point fdupes to the data directory instead of directly the build
  root, wich is a practice that must be avoided.
* Mon Apr  9 2018 bjorn.lie@gmail.com
- Update to version 3.28.1:
  + EOG is missing an icon in full screen mode
    (eog-image-gallery-symbolic) (bgo#794472).
  + Updated translations.
* Tue Mar 20 2018 dimstar@opensuse.org
- Unconditionally enable translation-update-upstream: on
  Tumbleweed, this results in a NOP and for Leap in SLE paid
  translations being used (boo#1086036).
* Mon Mar 12 2018 dimstar@opensuse.org
- Update to version 3.28.0:
  + Updated translations.
* Tue Mar  6 2018 dimstar@opensuse.org
- Update to version 3.27.91:
  + Build system improvements.
  + Bug fixes: bgo#793719.
  + Updated translations.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Tue Feb 13 2018 dimstar@opensuse.org
- Update to version 3.27.90:
  + Swapped shortcuts for gallery and sidebar to match other GNOME
    apps.
  + Disabled color profile generation from Exif values.
  + Replaced several deprecated Glib/Gtk+ function calls.
  + Bugs fixed: bgo#792682, bgo#792770, bgo#792923, bgo#792924,
    bgo#792925.
  + Updated translations.
* Thu Jan 11 2018 luc14n0@linuxmail.org
- Add gio-2.0, gio-unix-2.0, gsettings-desktop-schemas,
  gtk+-unix-print-3.0 and libpeas-1.0 pkgconfig modules
  BuildRequires aligning then with meson.build requirements.
* Wed Jan 10 2018 zaitor@opensuse.org
- Update to version 3.27.3:
  + Drop Autotools support in favour of Meson.
  + Drop deprecated/unused files from help docs.
  + Port to meson build system (bgo#784354).
- Drop configure macro.
- Minor spec modernization.
- Pass explicit options to meson, ensure we are building the
  features we want, currently aligned with upstream defaults apart
  from gtk_doc, where we put true as we want to build
  documentation.
- Following the above, add gtk-doc BuildRequires, and package the
  now built documentation.
* Sun Dec 17 2017 luc14n0@linuxmail.org
- Update to version 3.27.2:
  + Bug fixes:
  - Close confirmation dialog looks outdated (bgo#787188).
  - EOG 3.26 does not store recently used files (bgo#787750).
- Update Url to https://wiki.gnome.org/Apps/EyeOfGnome: current
  Eye of Gnome's web page.
* Tue Nov 14 2017 fezhang@suse.com
- Update to version 3.27.1:
  + Port to meson build system.
  + Bugs fixed: bgo#784354, bgo#790078.
- Add meson BuildRequires and switch autotools macros configure,
  make and makeinstall to meson, meson_build and meson_install
  following upstream switch to Meson build system.
* Fri Nov 10 2017 zaitor@opensuse.org
- Drop update-desktop-files BuildRequires and no longer pass
  suse_update_desktop_file macro, not needed anymore.
- Drop eog2 Provides and Obsoletes, no current openSUSE release
  have ever had eog2.
- Modernize spec, use autosetup and make_build macros.
* Thu Nov  9 2017 fezhang@suse.com
- Update to version 3.26.2:
  + Bugs fixed: bgo#788582, Wrong line endings and broken tags in
    eog's help.
  + Updated translations.
- Drop eog-spanish-translations.patch: Fixed upstream.
* Tue Oct 10 2017 zaitor@opensuse.org
- Add eog-spanish-translations.patch: Fix build with new itstool.
* Tue Oct  3 2017 luc14n0@linuxmail.org
- Update to version 3.26.1:
  + Updated manual translations.
  + Updated translations.
- Drop %%glib2_gsettings_schema_requires: no longer needed.
* Mon Sep 11 2017 zaitor@opensuse.org
- Update to version 3.26.0:
  + Updated translations.
- Conditionally apply translations-update-upstream BuildRequires
  and macro for non-openSUSE only.
- Run spec-cleaner, modernize spec.
* Mon Sep 11 2017 jengelh@inai.de
- Enhance package description, partly using the Debian text.
* Wed Sep  6 2017 luc14n0@linuxmail.org
- Update to version 3.25.92:
  + Bugs fixed: bgo#759434.
  + Updated translations.
* Mon Aug  7 2017 zaitor@opensuse.org
- Update to version 3.25.90:
  + Miscellaneous fixes.
  + Bugs fixed: bgo#784942.
  + Updated translations.
- Drop no longer needed post(un) handling, remove the following
  macros: glib2_gsettings_schema_post(un),
  desktop_database_post(un) and icon_theme_cache_post(un).
* Tue Jun 20 2017 dimstar@opensuse.org
- Update to version 3.25.1:
  + Drop intltool support in favour of plain gettext.
  + Be able to mount a volume from recent files (bgo#555831).
  + Updated translations.
- Drop intltool BuildRequires: no longer needed.
- Drop libtool BuildRequires: this was added 6 years ago 'to make
  build more reliable'. Since then, the build system has improved
  a lot.
* Mon Apr 24 2017 dimstar@opensuse.org
- Update to version 3.24.1:
  + bgo#780675: gcc pragma build failure.
  + Updated translations.
* Mon Mar 20 2017 dimstar@opensuse.org
- Update to version 3.24.0:
  + Updated translations.
* Tue Mar 14 2017 zaitor@opensuse.org
- Update to version 3.23.92:
  + Updated translations.
* Tue Feb 28 2017 zaitor@opensuse.org
- Update to version 3.23.91:
  + Various fixes for the new zoom widget.
  + Make zoom menu wider (bgo#778573).
  + Updated translations.
* Wed Feb 15 2017 dimstar@opensuse.org
- Update to version 3.23.90:
  + Replace zoom scale with a text entry based on Evince's zoom
    widget.
  + Fix keyboard navigation in the headerbar and popup menu.
  + Bugs fixed: bgo#754985.
  + Updated translations.
* Tue Jan 17 2017 dimstar@opensuse.org
- Update to version 3.23.1:
  + Several GTK deprecation fixes.
  + Smaller bug and memory leak fixes.
  + Bugs fixed: bgo#774001, bgo#776984.
  + Updated translations.
* Tue Oct 11 2016 zaitor@opensuse.org
- Update to version 3.20.5:
  + Some smaller code improvements.
  + Bug fixes: bgo#772162: When deleting ALL images, the last one
    stays in preview.
  + Updated translations.
* Sun Aug 21 2016 zaitor@opensuse.org
- Update to version 3.20.4 (boo#994819):
  + Out-of-bounds fix (bgo#770143, CVE-2016-6855).
  + eog leaks error message if loading an SVG fails (bgo#770197).
  + Updated translations.
* Mon Jun 20 2016 zaitor@opensuse.org
- Update to version 3.20.3:
  + Eye Of Gnome should refresh automatically the image when it is
    edited (bgo#767003).
  + Updated translations.
* Mon May 16 2016 mgorse@suse.com
- Update to GNOME 3.20.2  Fate#318572
* Mon May  9 2016 zaitor@opensuse.org
- Update to version 3.20.2:
  + Updated translations.
* Wed Apr 13 2016 hpj@suse.com
- Update to GNOME 3.20, Fate#318572.
* Tue Apr 12 2016 zaitor@opensuse.org
- Update to version 3.20.1:
  + Improved startup time especially on remote shares.
  + Miscellaneous fixes and improvements.
  + Bugs fixed: bgo#665897, bgo#764139.
  + Updated translations.
* Tue Mar 22 2016 dimstar@opensuse.org
- Update to version 3.20.0:
  + Updated translations.
* Tue Mar 15 2016 dimstar@opensuse.org
- Update to version 3.19.92:
  + Code improvements.
  + bgo#763505: EogPrintPreview: Silence -Wsign-compare and
  - Wswitch-default.
  + Updated translations.
* Mon Feb 29 2016 zaitor@opensuse.org
- Update to version 3.19.91:
  + Updated translations.
* Mon Feb 15 2016 zaitor@opensuse.org
- Update to version 3.19.90:
  + Better image quality when downscaling.
  + Improved AppData.
  + Improved strings in the shortcuts window.
  + Bugs fixed: bgo#665897, bgo#761408, bgo#762028.
  + Updated translations.
* Sun Feb 14 2016 dimstar@opensuse.org
- Update to version 3.19.4:
  + Small application menu improvements.
  + Updated translations.
* Sun Feb 14 2016 zaitor@opensuse.org
- Update to version 3.19.3:
  + Convert custom CSS to use CSS nodes (bgo#758763).
  + Add a shortcuts window (bgo#757827).
  + Updated translations.
* Sun Feb 14 2016 zaitor@opensuse.org
- Update to version 3.19.2:
  + Further UI improvements.
  + Bugs fixed: bgo#754628.
  + Updated translations.
* Sun Feb 14 2016 zaitor@opensuse.org
- Update to version 3.19.1:
  + Various UI improvements.
  + Bugs fixed: bgo#754628, bgo#754985, bgo#755244, bgo#755799.
  + Updated translations.
* Sun Feb 14 2016 zaitor@opensuse.org
- Update to version 3.18.2:
  + bgo#762028: >=eog-3.14 is affected by CVE-2013-7447.
  + Updated translations.
* Mon Nov  9 2015 zaitor@opensuse.org
- Update to version 3.18.1:
  + Some entries of the popovermenu entry should be grayed when no
    image opened (bgo#755244).
  + Updated translations.
* Tue Sep 29 2015 zaitor@opensuse.org
- Update to version 3.18.0:
  + Updated translations.
* Wed Sep 16 2015 dimstar@opensuse.org
- Update to version 3.17.92:
  + bgo#754731: Use standard::display-name for Google Drive items.
  + Updated translations.
* Tue Sep  1 2015 zaitor@opensuse.org
- Update to version 3.17.91:
  + Access key is not assigned to button "Open with Document
    Viewer" (bgo#753987).
  + Compilation cleanups (bgo#754104).
  + Updated translations.
* Mon Aug 17 2015 zaitor@opensuse.org
- Update to version 3.17.90:
  + Add touchpad gesture event mask to EogScrolledWindow
    (bgo#753627).
  + Updated translations.
* Mon Aug 17 2015 zaitor@opensuse.org
- Update to version 3.17.3:
  + Updated translations.
* Mon Aug 17 2015 zaitor@opensuse.org
- Update to version 3.17.2:
  + Bugs fixed: bgo#746132, bgo#751007, bgo#751021.
  + Updated translations.
* Mon Aug 17 2015 zaitor@opensuse.org
- Update to version 3.17.1:
  + Small improvements for the new UI.
  + Bug fixes and code improvements.
  + Bugs fixed: bgo#538279, bgo#739654, bgo#743477, bgo#746802,
    bgo#748598.
  + Updated translations.
* Mon Aug 17 2015 zaitor@opensuse.org
- Update to version 3.16.3:
  + Fix bgo#751007: Compilation error when EXIF support disabled.
  + Updated translations.
* Thu May 14 2015 zaitor@opensuse.org
- Update to version 3.16.2:
  + Install symbolic app icon.
  + Bugs fixed: bgo#746842, bgo#747806, bgo#748653.
  + Updated translations.
* Wed Apr 15 2015 dimstar@opensuse.org
- Update to version 3.16.1:
  + bgo#735633: eog crashes when attempting two-finger zoom gesture
    on touchpad.
  + bgo#747410: regression: default zoom incorrect when browsing.
  + Updated translations.
* Mon Mar 23 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + remove the overlay timeout in dispose (bgo#745336).
  + Updated translations.
* Tue Mar 17 2015 dimstar@opensuse.org
- Update to version 3.15.92:
  + Improvements to UI changes based on initial feedback.
  + Adjust UI tests for UI changes.
  + Bugs fixed: bgo#745077, bgo#746105.
  + Updated translations.
* Tue Feb 17 2015 dimstar@opensuse.org
- Update to version 3.15.90:
  + More cleanup after the first round of UI modernization.
  + Make GAction plugin interface actually usable by plugins
    NOTE: Plugins using the old GtkUIManager interface won't work
    anymore!
  + Bugs fixed: bgo#743887.
  + Updated translations.
* Tue Feb  3 2015 dimstar@opensuse.org
- Update to version 3.15.1:
  + Modernize the GUI.
  + Migrate to GAction.
  + Bugs fixed: bgo#740426, bgo#741050, bgo#742369.
  + Updated translations.
- Drop pkgconfig(libxml-2.0) BuildRequires: no longer needed.
* Wed Nov 19 2014 zaitor@opensuse.org
- Update to version 3.14.3:
  + Fix preferences dialog when using aggressive linker settings
    (bgo#739618).
  + Fixed a few memory leaks (bgo#740348).
  + Updated translations.
* Thu Nov 13 2014 zaitor@opensuse.org
- Update to version 3.14.2:
  + Updated translations.
* Mon Oct 13 2014 dimstar@opensuse.org
- Update to version 3.14.1:
  + Bugs fixed: bgo#737213, bgo#737772, bgo#737960.
  + Updated translations.
* Thu Oct  9 2014 dimstar@opensuse.org
- Delete libtool archives after build.
* Mon Sep 22 2014 zaitor@opensuse.org
- Update to version 3.14.0:
  + Updated translations.
* Mon Sep 15 2014 zaitor@opensuse.org
- Update to version 3.13.92:
  + Updated translations.
* Mon Aug 18 2014 dimstar@opensuse.org
- Update to version 3.13.90:
  + Touchscreen gestures support (bgo#730656).
  + Updated UI tests.
  + Fix more deprecated GTK+ usage.
  + Updated translations.
* Tue Jul 22 2014 dimstar@opensuse.org
- Update to version 3.13.3:
  + Drop deprecated GtkMisc and GtkAlignment usage.
  + Improvements to GUI test handling.
  + Updated translations.
* Sat Jul 12 2014 dimstar@opensuse.org
- Update to version 3.13.2:
  + Convert dialogs made with Glade to GResource and widget
    templates.
  + Bugs fixed: bgo#729494, bgo#729498.
  + Updated translations.
* Sat May 17 2014 zaitor@opensuse.org
- Update to version 3.13.1:
  + Added installed GUI tests.
  + Support extracting color profiles with GdkPixbuf.
  + Drop gnome-icon-theme dependency.
  + Bugs fixed: bgo#727467, bgo#727989, bgo#729018.
  + Updated translations.
- Drop pkgconfig(gnome-icon-theme) BuildRequires: No longer needed.
* Sat May 17 2014 zaitor@opensuse.org
- Update to version 3.12.2:
  + Disable dark theme plugin does not disable the dark theme
    (bgo#729494).
  + Plugin manager not resizing in the preferences window
    (bgo#729498).
  + Updated translations.
* Mon Apr 14 2014 zaitor@opensuse.org
- Update to version 3.12.1:
  + Updated translations.
* Tue Mar 25 2014 dimstar@opensuse.org
- Update to version 3.12.0:
  + Updated translations.
* Tue Mar 18 2014 dimstar@opensuse.org
- Update to version 3.11.92:
  + bgo#720340: 'save as' doesn't update window title.
  + Updated translations.
* Mon Mar  3 2014 dimstar@opensuse.org
- Update to version 3.11.91:
  + Improved color management compatibility.
  + Improved Exif GPS tag handling.
  + Bugs fixed: bgo#554498, bgo#725357, bgo#725416.
  + Updated translations.
* Mon Feb 17 2014 zaitor@opensuse.org
- Update to version 3.11.90:
  + Bugs fixed: bgo#722235, bgo#723544, bgo#723546.
  + Updated translations.
* Mon Jan 13 2014 dimstar@opensuse.org
- Update to version 3.11.4:
  + Use Python 3.x for Python plugins.
  + AppData improvements.
  + Misc improvements and optimizations.
  + Bugs fixed: bgo#721488, bgo#721755.
  + Updated translations.
* Mon Dec 16 2013 dimstar@opensuse.org
- Update to version 3.11.3:
  + Image background layer uses GdkRGBA to avoid color conversion
    from GdkColor and principally allow transparent backgrounds.
  + Make several actions available over D-Bus.
  + Fixed more deprecated GtkStyle and GtkStock usage.
  + Bugs fixed: bgo#712350, bgo#720144.
  + Updated translations.
* Tue Nov 19 2013 dimstar@opensuse.org
- Update to version 3.11.2:
  + Various improvements and bugfixes: bgo#509406, bgo#700717,
    bgo#712354.
  + Updated translations.
* Sun Nov 17 2013 dimstar@opensuse.org
- Update to version 3.11.1:
  + Use GtkOverlay and GtkRevealer for fullscreen toolbar.
  + * Add AppData support.
  + * Build system improvements.
  + * Replace several deprecated APIs.
  + * Various improvements and bugfixes.
  + Bugs fixed: bgo#582931, bgo#708757.
  + Updated translations.
* Tue Nov 12 2013 dimstar@opensuse.org
- Update to version 3.10.2 (bnc#849913):
  + Fix detail widget expansion in properties dialog.
  + Updated translations.
* Tue Oct 15 2013 dimstar@opensuse.org
- Update to version 3.10.1:
  + Updated translations.
* Tue Sep 24 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + Add translator comment to "Viewing a slideshow" (bgo#708554).
  + Updated translations.
* Fri Sep 13 2013 zaitor@opensuse.org
- Update to version 3.9.92:
  + Updated translations.
* Sun Sep  8 2013 zaitor@opensuse.org
- Stop passing --disable-scrollkeeper to configure, no longer
  recognized nor needed.
* Tue Sep  3 2013 dimstar@opensuse.org
- Update to version 3.9.91:
  + Build system fixes.
  + Miscellaneous fixes and cleanups.
  + Bugs fixed: bgo#706837, bgo#707099, bgo#707212.
  + Updated translations.
- Changes from version 3.9.90:
  + Updated translations.
* Tue Jul 30 2013 dimstar@opensuse.org
- Update to version 3.9.5:
  + Bugs fixed: bgo#683908, bgo#702521, bgo#702523, bgo#704074,
    bgo#704359,
  + Updated translations.
- No longer install eog-uri-converter.h manually: make install
  takes care of it.
* Fri Jul 12 2013 dimstar@opensuse.org
- Manually install eog-uri-converter.h: the header is wrongly
  marked as NOINST, but is referenced by eog-uri-jobs.h.
  The install command will fail when the file is installed by make
  install.
* Fri Jun 21 2013 dimstar@opensuse.org
- Update to version 3.9.1:
  + Integrate more modern job system from Evince with proper
    cancellation support in preparation for further refactoring.
  + Bugs fixed: bgo#563538, bgo#630512, bgo#699043.
  + Updated translations.
* Mon May 13 2013 dimstar@opensuse.org
- Update to version 3.8.2:
  + Eog initial window size exceeds screen height (bgo#630512).
- Changes from version 3.8.1:
  + Updated translations.
* Mon Mar 25 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + Updated translations.
* Tue Mar 19 2013 zaitor@opensuse.org
- Change group of eog-devel into Development/Libraries/GNOME,
  silences lint warning.
* Mon Mar 18 2013 dimstar@opensuse.org
- Update to version 3.7.92:
  + Disable color management support on !X (bgo#695818).
  + Updated translations.
* Tue Mar  5 2013 dimstar@opensuse.org
- Update to version 3.7.91:
  + Updated translations.
* Tue Jan 15 2013 dimstar@opensuse.org
- Update to version 3.7.4:
  + Use XDG_DATA_DIRS and XDG_DATA_HOME as plugin search paths.
  + Bugs fixed: bgo#683335, bgo#689165, bgo#690282, bgo#690931,
    bgo#691517, bgo#691552.
  + Updated translations.
* Sun Nov 25 2012 dimstar@opensuse.org
- Update to version 3.7.2:
  + Build system improvements / fixes.
  + Bugs fixed: bgo#687755.
  + Updated translations.
* Wed Nov 14 2012 dimstar@opensuse.org
- Update to version 3.7.1:
  + Switch to GtkApplication for inhibiting the screensaver.
  + Misc. improvements/fixes.
  + Bugs fixed: bgo#684098, bgo#684179, bgo#684581.
  + Updated translations.
* Tue Nov 13 2012 dimstar@opensuse.org
- Update to version 3.6.2:
  + Updated translations.
* Mon Oct 15 2012 dimstar@opensuse.org
- Update to version 3.6.1:
  + Bugs fixed: bgo#685106, bgo#685923.
  + Updated translations.
* Mon Sep 24 2012 dimstar@opensuse.org
- Update to version 3.6.0:
  + Linking fails with undefined floor symbol (bgo#684401)
  + Updated translations.
* Wed Sep 19 2012 dimstar@opensuse.org
- Update to version 3.5.92:
  + After printing the number of copies are saved globally
    (bgo#623604)
  + Updated translations.
* Mon Sep  3 2012 dimstar@opensuse.org
- Update to version 3.5.91:
  + Unify navigation in zoomed and unzoomed modes
  + Bugs fixed: bgo#659830, bgo#682534
  + Updated translations.
* Mon Aug 20 2012 dimstar@opensuse.org
- Update to version 3.5.90:
  + Updated documentation
  + Build help using yelp-tools instead of gnome-doc-utils
  + Support for per-instance plugins
  + Bugs fixed: 682028
  + Updated translations.
- Replace gnome-doc-utils-devel BuildRequires with yelp-tools,
  following upstream.
* Mon Aug  6 2012 dimstar@opensuse.org
- Update to version 3.5.4:
  + Provide an application menu (bgo#674938)
  + Updated translations.
* Tue Jul 24 2012 dimstar@opensuse.org
- Update to version 3.5.3:
  + bgo#679505: Dialog for saving multiple images is too small
  + Updated translations.
* Mon Jul 23 2012 dimstar@opensuse.org
- Update to version 3.5.2:
  + bgo#669830: eog fails to display a jpg image - and just hangs
  + bgo#675569: Refuses to save file after horizontal flip:
    "Maximum supported image dimension is 65500 pixels"
  + bgo#676461: build: OpenBSD needs _XOPEN_SOURCE_EXTENDED
    for strptime(3)
  + bgo#676486: Missing scrollbars when zooming a SVG image
  + bgo#677168: Image Gallery not displayed correctly with
    GTK+-3.4.3
  + bgo#677200: Race condition: misbehaves when launched twice
  + Updated translations.
* Sun Jul 22 2012 dimstar@opensuse.org
- Update to version 3.5.1:
  + Try to avoid recompressing JPG images to PNG for printing
  + Choose default paper orientation based on image dimension
  + Bugs fixed: bgo#394260, bgo#531898, bgo#579595, bgo#658127.
* Sun Jul 22 2012 zaitor@opensuse.org
- Start using new upstream name Image Viewer, fixes bnc#772554.
  Having a different name for the desktoplauncher and what the
  application is named could confuse users.
* Sun Jul 15 2012 zaitor@opensuse.org
- Update to version 3.4.3:
  + Fix broken image gallery due to recent changes in GtkIconView.
  + bgo#677168, Image Gallery not displayed correctly with
    GTK+-3.4.3.
  + bgo#679505, Dialog for saving multiple images is too small.
  + Updated translations.
* Sun Jun 10 2012 dimstar@opensuse.org
- Update to version 3.4.2:
  + bgo#675569: Refuses to save file after horizontal flip:
    "Maximum supported image dimension is 65500 pixels"
  + bgo#676486: Missing scrollbars when zooming a SVG image
  + bgo#677200: Race condition: misbehaves when launched twice in
    quick succession
  + Updated translations.
* Tue Apr 17 2012 vuntz@opensuse.org
- Update to version 3.4.1:
  + Extend help docs.
  + Updated translations.
* Mon Mar 26 2012 zaitor@opensuse.org
- Update to version 3.4.0:
  + Updated translations.
* Tue Mar 20 2012 zaitor@opensuse.org
- Update to version 3.3.92:
  + Fix crash with gtk+-3.3.18 and X.Org server 1.12.
  + Various code cleanups and fixes.
  + Bug fixes: bgo#671402, bgo#671643, bgo#671944, bgo#672312.
  + Updated translations.
* Mon Mar  5 2012 dimstar@opensuse.org
- Update to version 3.3.91:
  + More deprecated code removal (bgo#671008)
  + Documentation improvements (bgo#670245)
  + Various fixes & improvement (bgo#670700, bgo#671038,
    bgo#671202)
  + Updated translations.
* Tue Feb 21 2012 vuntz@opensuse.org
- Update to version 3.3.90:
  + Relayout metadata sidebar to require less horizontal space
  + Lots of - mostly deprecated - code cleanup (bgo#670183,
    bgo#670184, bgo#670185)
  + Updated translations.
- Change libexempi-devel BuildRequires to pkgconfig(exempi-2.0).
* Tue Feb  7 2012 vuntz@opensuse.org
- Update to version 3.3.5:
  + Hide titlebar when window is maximised (bgo#668652)
  + Miscellaneous bug fixes (bgo#563760, bgo#664747, bgo#668178)
  + Updated translations.
- Remove xz BuildRequires now that it comes for free in the build
  system.
* Tue Jan 17 2012 vuntz@opensuse.org
- Update to version 3.3.4:
  + Use scrollwheel to change scale in image preview (bgo#495716)
  + Support for symlinks when dragging image to folder (bgo#667076)
  + Build failure upgrading from 3.3.2 to 3.3.3 (bgo#666556)
  + Updated translations.
* Tue Dec 20 2011 vuntz@opensuse.org
- Update to version 3.3.3:
  + Extend "Open containing folder" to use Nautilus' new DBus API
    (bgo#650402)
  + Make metadata summaries available as sidebar again
    (bgo#616438)
  + Replace lots of deprecated APIs
  + Various fixes/improvements (including bgo#607287)
  + Updated translations.
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
* Tue Nov 22 2011 vuntz@opensuse.org
- Update to version 3.3.2:
  + Fix deadlock with recently changed GApplication-behaviour
    (bgo#662630)
  + Automatically reload unmodified images when the file changes
    (bgo#555370)
  + Try to preserve file attributes when saving (bgo#653065)
  + Allow reusing a window from the commandline (bgo#617735)
  + Improved help docs
  + Other bug fixes: bgo#614869, bgo#655205, bgo#661325.
  + Updated translations.
* Tue Nov 15 2011 vuntz@opensuse.org
- Update to version 3.2.2:
  + Updated translations.
* Mon Oct 17 2011 dimstar@opensuse.org
- Update to version 3.2.1:
  + Updated translations.
* Fri Sep 30 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Mon Sep 26 2011 vuntz@opensuse.org
- Update to version 3.2.0:
  + Updated translations.
* Wed Sep 21 2011 vuntz@opensuse.org
- Update to version 3.1.92:
  + Build system fixes/improvements (including bgo#659093).
  + Updated translations.
- Drop eog-fix-doc-figures.patch: fixed upstream.
- Remove gnome-common BuildRequires and call to autoreconf: they
  were only needed for the patch above.
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant/obsolete tags/sections from specfile
  (cf. packaging guidelines)
- Use %%_smp_mflags for parallel build
* Wed Sep 14 2011 vuntz@opensuse.org
- Add eog-fix-doc-figures.patch: fix installation of doc figures so
  we don't install non-existing figures, that would result in
  broken links -- those will break the build of bundle-lang-gnome.
- Add gnome-common BuildRequires and call to autoreconf, needed for
  the patch above.
* Tue Sep  6 2011 vuntz@opensuse.org
- Update to version 3.1.91:
  + Use 'Image Viewer' in all UI visible strings instead of 'Eye of
    GNOME' (bgo##658152)
  + Internationalization fixes (bgo##654548)
  + Major help update
  + Updated translations.
- Stop changing categories of eog.desktop: they're correct
  upstream.
* Wed Aug 31 2011 vuntz@opensuse.org
- Update to version 3.1.90:
  + Decrease the fullscreen toolbar timeout to match other popular
    applications
  + Updated translations.
* Tue Aug 16 2011 dimstar@opensuse.org
- Update to version 3.1.5:
  + Render compressed SVGs using librsvg as well
  + Enable fullscreen plugin by default
  + Miscellaneous fixes/improvements
  + Bugs fixed: bgo#552537, bgo#655377, bgo#655794, bgo#655889.
  + Updated translations.
* Mon Jul 25 2011 vuntz@opensuse.org
- Update to version 3.1.4:
  + Stop silently ignoring errors while saving images (bgo#615376)
  + Improve display of GPS Exif tags (bgo#627185)
  + Miscellaneous fixes/improvements
  + Bug fixes: bgo##653162.
  + Updated translations.
* Wed Jun 15 2011 dimstar@opensuse.org
- Update to version 3.1.2:
  + New "Show containing folder" command
  + Improved SVG decoding
  + Better orientation support for TIFF and non-exif formats
  + Port from dbus-glib to GtkApplication
  + Misc. code improvements
  + Documentation improvements
  + Bugs fixed: bgo#649894, bgo#650402, bgo#642725, bgo#544068,
    bgo#548474, bgo#615114, bgo#622876.
  + Updated translations.
- Remove now unneeded pkgconfig(dbus-glib-1) BuildRequires.
* Tue May 17 2011 dimstar@opensuse.org
- Update to version 3.1.1:
  + Rewrite help docs using Mallard
  + Upgrade to use Little CMS 2 library for color profiling
  + Improve preferences dialog appearance
  + Miscellaneous fixes/improvements
  + Bugs fixed: bgo#646623, bgo#648440, bgo#648055, bgo#648833.
  + Updated translations.
- Replace pkgconfig(lcms) BuildRequires with pkgconfig(lcms2).
* Wed Apr 27 2011 fcrozat@novell.com
- Update to version 3.0.1:
  + Updated translations.
* Tue Apr  5 2011 fcrozat@novell.com
- Update to version 3.0.0:
  + Updated translations.
* Tue Mar 22 2011 fcrozat@novell.com
- Update to version 2.91.92:
  + bgo#644417: Update GSettings key for desktop background
  + bgo#644631: Use gnome-session d-bus api to inhibit screensaver
* Tue Mar  8 2011 fcrozat@novell.com
- Update to version 2.91.91:
  + Fix ref-count issue with python plugins ()
  + bgo#642969: Open correct capplet when setting background image
  + Miscellaneous fixes
  + Updated translations.
* Wed Mar  2 2011 vuntz@opensuse.org
- Add pkgconfig(gobject-introspection-1.0) BuildRequires.
* Tue Feb 22 2011 fcrozat@novell.com
- Update to version 2.91.90:
  + Bug fixed: bgo#641107.
  + Updated translations.
- Changes from version 2.91.7:
  + Fixed build on systems without GDK-2.x
  + Bug fixed: bgo#628547, bgo#639921.
  + Updated translations.
- Changes from version 2.91.6:
  + The plugin system was converted to libpeas
  + Basic support for GObject Introspection
  + Support copying an image to the clipboard
  + More GTK+-3.0 compatibility fixes
  + Bug fixed: bgo#78514, bgo#626091, bgo#626257, bgo#639312.
  + Updated translations.
- Changes from version 2.91.5:
  + Fix build with GTK+ 2.91.7
- Changes from version 2.91.4:
  + Fix unwanted image reloads for accidential drag&drops
  + Initially use page settings from system print queue
  + Bug fixed: bgo#549039, bgo#585069.
  + Updated translations.
- Changes from version 2.91.3:
  + Finish GSettings conversion
  + Fix build with latest GNOME 3 APIs
  + Bug fixed: bgo#620121, bgo#622161, bgo#634907, bgo#634942.
  + Updated translations
- Changes from version 2.91.2:
  + Migrate to XDG folders for config files
  + Adapt to API changes in latest GTK+
  + Bug fixed: bgo#522806, bgo#589921, bgo#632458, bgo#632608,
    bgo#632954, bgo#633746.
  + Updated translations.
- Changes from version 2.91.1:
  + Distributor-configurable "Edit Image" toolbar button
  + Make "Best Fit" a toggleable state of the image view
  + Bugs fixed: bgo#609958, bgo#614634, bgo#616890, bgo#623271,
    bgo#631710, bgo#632290.
  + Updated translations.
- Changes from version 2.91.0:
  + Switch rendering from GDK to cairo
  + Request a dark theme variant for the UI
  + Improved compatibility with GTK+-3
  + Draw images against black background by default to gain a
    better contrast
  + Copy image to disk when setting as desktop background when
    it is located on removable media
  + Ask user whether to reload an externally modified image
  + Improve GSettings-usage
  + New toolbar button and shortcut to pause the slideshow
  + Bugs fixed: bgo#534348, bgo#553283, bgo#613056, bgo#616450,
    bgo#618886, bgo#624261, bgo#624262, bgo#625226, bgo#625325,
    bgo#625384, bgo#626569, bgo#626795, bgo#628148, bgo#630686.
  + Updated translations.
- Change pkgconfig() BuildRequires:
  + change gnome-desktop-2.0 to gnome-desktop-3.0, gtk+-2.0 to
    gtk+-3.0
  + remove pygobject-2.0, pygtk-2.0
  + add libpeas-gtk-1.0
- Remove explicit Requires of gconf2-devel and gtk2-devel in devel
  subpackage: the right Requires will automatically be added the
  pkgconfig() way.
- Remove pkgconfig(gconf-2.0) BuildRequires and
  %%gconf_schemas_prereq. Do not pass --disable-schemas-install to
  %%configure, since this is needed for gconf only.
- Use %%glib2_gsettings_schema_* macros.
* Sun Feb 13 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
- Remove 2.x references in summaries and descriptions.
* Tue Nov 16 2010 dimstar@opensuse.org
- Update to version 2.32.1:
  + bgo#622161: EOG + "Date in statusbar" plugin hangs with
    specific PNG pictures
  + bgo#623271: freezes on named pipe
  + bgo#631710: displays garbage at bottom of image
  + bgo#632290: eog does not save changes if image is rotated and
    flipped once
  + Updated translations.
* Mon Sep 27 2010 vuntz@opensuse.org
- Update to version 2.32.0:
  + Updated translations.
* Wed Sep 15 2010 vuntz@opensuse.org
- Update to version 2.31.92:
  + Copy image to disk when setting as desktop background when it
    is located on removable media
  + Ask user whether to reload an externally modified image
  + Miscellaneous code fixes
  + Bug fixes:
  - bgo#613056: Side pane always shown at startup when plug-in is
    activated
  - bgo#614634: EOG prevents the Desktop thumbnails to be updated
  - bgo#625384: Background setting doesn't work as expected
  + Updated translations.
* Tue Sep  7 2010 vuntz@opensuse.org
- Change old-style BuildRequires to pkgconfig() style
  BuildRequires:
  + old-style: gnome-desktop-devel, gnome-icon-theme,
    libexif-devel, liblcms-devel, librsvg-devel, python-gtk-devel,
    shared-mime-info
  + new-style: dbus-glib-1, gconf-2.0, gdk-pixbuf-2.0, glib-2.0,
    gnome-desktop-2.0, gnome-icon-theme, gtk+-2.0, lcms, libexif,
    librsvg-2.0, libxml-2.0, pygobject-2.0, pygtk-2.0,
    shared-mime-info.
- This will make it easier to switch to GNOME 3 libraries.
* Mon Aug 30 2010 vuntz@opensuse.org
- Update to version 2.31.91:
  + bgo#628148: Miscellaneous string fixes
  + Updated translations.
* Tue Aug 17 2010 dimstar@opensuse.org
- Update to version 2.31.90:
  + Draw images against black background by default to gain a
    better contrast
  + Backport UI elements from master to change background color
  + Code improvements
  + bgo#616450: Use a nicer background colour
  + bgo#625325: Useless Yes/No question
  + bgo#626569: Button bar appears when deleting in fullscreen
  + Updated translations.
* Fri Aug  6 2010 vuntz@opensuse.org
- Update to version 2.31.5:
  + New toolbar button and 'P' shortcut to pause the slideshow
  + UI improvements
  + Code improvements
  + This is based on a new branch, started from 2.30.2, including
    all the changes from previous 2.31.x releases except migration
    to GSettings and GTK+ 3.0.
  + Updated translations.
- Changes from version 2.31.4:
  + Rename "Image Collection" to "Image Gallery" (bgo#618304)
  + Update totem-scrsaver to use GDBus (bgo#621439)
  + Build fixes (including bgo#621616)
  + Optimize GSettings-usage and fix key names (including
    bgo#621370)
  + Updated translations.
- Changes from version 2.31.3:
  + Begin GSettings migration
  + Allow using a custom background color for the image view
    (bgo#502992)
  + Updated translations.
- Changes from version 2.31.2:
  + Make eog fully GSEAL-compilant (bgo#606883)
  + Updated translations.
- Changes from version 2.31.1:
  + Render SVGs natively when zoomed (bgo#108435)
  + Print SVGs as vector image (bgo#518055)
  + Embed page setup in print dialog (bgo#614451)
  + Add high resolution app icon (bgo#615356)
  + Various UI improvements (including bgo#614405, bgo#614457,
    bgo#614497)
  + Further GSEAL-compatibility work
  + bgo#615344, Does not show external linked images that the URI
    is relative path in svg
  + bgo#615387, libjpeg-8 breaks lossless JPEG modification
  + bgo#615531, Please support --version
  + Updated translations.
- Changes from version 2.30.2:
  + bgo#621616, eog-2.30.1 fails to configure when
  - -without-libjpeg is passed
  + Updated translations.
- Fix self-obsoletion of eog2.
* Fri Jun  4 2010 sbrabec@suse.cz
- Added support for translation-update-upstream (FATE#301344).
* Thu Apr 29 2010 dimstar@opensuse.org
- Update to version 2.30.1:
  + bgo#615387, libjpeg-8 breaks lossless JPEG modification
  + Updated translations.
* Mon Mar 29 2010 vuntz@opensuse.org
- Update to version 2.30.0:
  + Updated translations.
* Tue Feb 23 2010 vuntz@opensuse.org
- Update to version 2.29.91:
  + Build fixes (bgo#609184, bgo##610692)
  + Updated translations.
* Wed Feb 10 2010 lmedinas@opensuse.org
- Update to version 2.29.90:
  + Further GSEAL-compatibility improvements
  + Allow switching to a random image from the collection
  + Build fixes
  + Ask user if he actually needs the Appearance capplet after
    setting a new desktop wallpaper through Eye of GNOME
  + Bug fixes:
  - bgo#606935, "Change desktop background" dialog shows up when
    using "Set as desktop wallpaper" option in image viewer
  - bgo#609184, Build failure: doesn't look for some required
    libs
  + Translation updates.
* Wed Jan 13 2010 captain.magnus@opensuse.org
- Update to version 2.29.5:
  + Remember last save location during session (bgo#604230)
  + String fixes / improvements (bgo#605851, bgo#605852)
  + Improve GSEAL-compatibility
  + Use GtkInfoBar widget for the error message area
  + Translation updates.
* Wed Dec  2 2009 vuntz@opensuse.org
- Update to version 2.29.3:
  + Code fixes / improvements
  + Updated translations.
- Changes from version 2.29.2:
  + Add dialog asking to save changes on exit
  + Build system fixes
  + bgo#322243, eog doesn't ask whether to save changes
  + bgo#600893, don't use LOCALMODLIBS in the configure
  + Updated translations.
* Sat Nov 14 2009 vuntz@opensuse.org
- Update to version 2.29.1:
  + Support for animated GIFs
  + Enhance statusbar translatability
  + Code fixes/improvements
  + Bug fixes:
  - bgo#335093, Support for animated images
  - bgo#566104, Reverse Left/Right arrows action in RTL mode
  - bgo#597059, Make statusbar info string translatable
  - bgo#597754, Incorrect behavior when slideshow delay is set to
    0 seconds
  + Updated translations.
* Tue Sep 22 2009 dimstar@opensuse.org
- Update to version 2.28.0:
  + Updated translations.
* Wed Sep  9 2009 vuntz@opensuse.org
- Update to version 2.27.92:
  + bgo#592945, Images not automatically rotated
  + bgo#594403, Display order is broken in some locales
  + Updated translatins.
* Tue Aug 25 2009 vuntz@novell.com
- Update to version 2.27.91:
  + Make "Open With..." plugin look more like Nautilus's
  + Code fixes / improvements
  + Updated translations.
* Wed Aug 12 2009 captain.magnus@opensuse.org
- Update to version 2.27.90:
  + Fix crashes with plugins using Clutter 1.0
  + Make netbook-mode and xdg-fallback always enabled
  + Support Automake 1.11's silent build rules
  + Generate ChangeLog from git history
  + Build system fixes
  + bgo#590124, Eog fails to compile if exempi/exif are not
    available
  + Translation updates
* Tue Jul 28 2009 lmedinas@gmail.com
- Update to version 2.27.5:
  + Add option to move the detailled metadata list on its own page
    in the image properties dialog; useful on small screens
  + Add option to have filechooser show the XDG pictures folder by
    default if no image is loaded
  + Code improvements
  + Build system improvements / fixes
  + Bug fixes:
  - bgo#566810, Image properties dialog too big for netbooks
  - bgo#589151, Let filechooser fall back to user's pictures
    folder
  - bgo#589584, always show icon for rotate/flip menu items
  + Updated translations.
* Sun Jul 19 2009 bjorn.lie@gmail.com
- Update to version 2.27.4:
  + Allow having a "Save" button on the toolbar
  + Try to realise the main window from the main loop to reduce
    the risk of crashes when clutter-using plugins use the sidebar.
  + New and updated translations.
* Tue Jun 16 2009 vuntz@novell.com
- Update to version 2.27.3:
  + bgo#585357, Undefined entity in .de helpfile
  + Updated translations.
* Wed May 27 2009 vuntz@novell.com
- Update to version 2.27.2:
  + Interpolation controllable independently for zoom-in and
    zoom-out
  + Code improvements / fixes
  + Bug fixes:
  - bgo#491197, Avoiding zoom-in blurriness
  - bgo#583268, properties in image properties dialog not
    selectable
  - bgo#583448, Crash on exif data
  + Updated translations.
* Tue May  5 2009 vuntz@novell.com
- Update to version 2.27.1:
  + Drop libart_lgpl dependency
  + Allow disabling trash confirmation dialog
  + Shortcut improvements
  + Reduce number of exported symbols
  + UI improvements
  + Code improvements / fixes
  + Bug fixes:
  - bgo#541967, Make possible to remove image with 'Delete'
    without being asked for confirmation
  - bgo#543158, Make deletion confirmation dialog optional during
    session
  - bgo#556378, "Best Fit" zoom setting should have a shortcut
  - bgo#557317, image collection's scroll bar doesn't have a
    proportional slider
  - bgo#571732, Get rid of deprecated libart_lgpl
  - bgo#575772, Move to Trash button has no accelerator
  - bgo#576558, Crashes when trying to save write protected file
  - bgo#579212, JPEG file causes memory corruption
  - bgo#580600, eog crashes on drag&drop a directory from places
    menu
  - bgo#581180, Set as background on Right click
  + Updated translations.
- Remove libart_lgpl-devel BuildRequires.
* Tue Apr 14 2009 vuntz@novell.com
- Update to version 2.26.1:
  + UI improvements
  + Code improvements / fixes
  + bgo#575772, Move to Trash button has no accelerator
  + bgo#576558, Crashes when trying to save write protected file
  + Updated translations.
* Mon Mar 16 2009 mboman@suse.de
- Update to version 2.26.0:
  + Translation updates
- Don't package omf files twice (they are in the lang package too).
- Remove scrollkeeper and python from BuildRequires
- Remove gnome-icon-theme from Requires
- Remove AutoReqProv from -devel package
- Remove libglade2-devel from Requires in -devel package
* Sun Mar  8 2009 vuntz@novell.com
- Review changes.
* Wed Mar  4 2009 lmedinas@gmail.com
- Update to version 2.25.92:
  + Code improvements / fixes
  + Typo fixes in UI / docs
  + bgo#550086, Rotate image counterclockwise shortcut
  + bgo#558086, simplify drag targets handling
  + bgo#572410, eog crashed with SIGSEGV in g_closure_invoke()
  + bgo#572723, Misspelled word in a window
  + bgo#572889, Possible typo
  + Translation updates
  + Documentation updates
- Added libart_lgpl-devel BuildRequires to fix build
* Tue Feb 17 2009 vuntz@novell.com
- Review changes.
* Tue Feb 17 2009 lmedinas@gmail.com
- Update to version 2.25.91:
  + Additional workaround for CVE-2008-5978
  + Fixed bgo#569228: untrusted python modules search path
  + Translation updates
* Thu Feb 12 2009 vuntz@novell.com
- Review changes.
* Wed Feb  4 2009 lmedinas@gmail.com
- Update to version 2.25.90:
  + Support for deleting files that can't be trashed
  + Build system improvements / fixes
  + Code improvements / fixes
  + Bugs fixed: bgo#441637, bgo#568410, bgo#568882, bgo#569657
    bgo#569855
  + Documentation Updates
  + Translation Updates
- Drop eog-update-pc.patch commited upstream
* Fri Jan 30 2009 vuntz@novell.com
- Drop docbook_4, gnutls-devel, indent, libidl, libwnck-devel and
  perl-XML-Parser BuildRequires
- Remove pkg-config Requires on the devel package.
- Move all gtk-doc related files to the devel package.
* Thu Jan 29 2009 lmedinas@gmail.com
- Update to version 2.25.5:
  + Code improvements / fixes
  + Drop libgnome dependency
  + Bugs fixed: bgo #559500, bgo #557662, bgo #566104, bgo #566190
  + Translation updates
- Remove unneeded dependencies: libgnomeui-devel, gnome-vfs2-devel,
  libgnomeprintui-devel, eel-devel
- Add libjpeg-devel dependency to fix build
- Drop eog-nullify-gerror-450055.patch already upstream
- Add eog-update-pc.patch to update eog-pc dependencies (bgo #569657)
* Wed Jan  7 2009 lmedinas@gmail.com
- Update to version 2.25.4:
  + Code improvements / fixes
  + Python bindings improvements
  + Fix bgo #566367
  + Translation updates
* Sat Dec 20 2008 mboman@suse.de
- Update to version 2.25.3:
  + Build system improvements
  + Code improvements / fixes
  + Fetch tooltip data asynchronously
  + UI enhancements
  + Workarounds to make remote images work again
  + Fix broken keyboard keys
  + String improvements
  + Code improvements
  + Bugs fixed: bgo#559579, bgo#514352, bgo#555480, bgo#558442, bgo#560070,
    bgo#560073, bgo#563570, bgo#564290, bgo#564526, bgo#559579, bgo#560065,
    bgo#560068, bgo#560336, bgo#560396, bgo#562119
  + Translation updates
* Fri Dec 12 2008 rodrigo@novell.com
- Nullify GError before sending it to g_file_copy (bnc#450055)
* Wed Oct 22 2008 mboman@suse.de
- Update to version 2.24.1:
  + Improvements to the JPEG metadata reader
  + Fix progress reporting when images only need copying during "Save As"
  + Fix some critical warnings
  + Do not open some images at 98%% or 99%%
  + Install metadata related headers properly
  + Avoid possible markup "injection attack"
  + Docs improvements.
  + Bugs fixed: bgo#530447, bgo#555940, bgo#555942
  + Translation updates
* Tue Sep 30 2008 mboman@suse.de
- Update to version 2.24.0:
  + bgo#552109, won't set wallpaper
  + Translation updates
* Wed Sep 10 2008 maw@suse.de
- Update to version 2.23.92:
  + Fixes in recent files management
  + Fixes drawing problems on the message area
  + Fixes "Operation not supported" error on save-as-many
  + Fixes the "reload image" plugin
  + Documentation improvement: more API reference
  + Bugs fixed: bgo#548392, bgo#504538, and bgo#550252
  + Updated translations.
* Tue Sep  2 2008 mboman@novell.com
- Update to version 2.23.91:
  + Fixes segfaults with XMP-only files
  + Do not fail to show current directory in the open file chooser
  + More robust handling of image loading errors
  + Sensible UI defaults if GConf fails
  + Misc UI improvements
  + Build system and docs improvements
  + Bugs fixed: bgo#548738, bgo#547466, bgo#548736
  + Translation updates.
* Tue Aug 26 2008 mboman@novell.com
- Update to version 2.23.90:
  + Build system improvements
  + Bug fixes: bgo#547302, bgo#547566, bgo#548079, bgo#548202
  + Translation updates.
* Fri Jun 20 2008 maw@suse.de
- Update to version 2.23.4.1:
  + Bugs fixed: bgo#526483, bgo#537488, and bgo#537758
  + Updated translations.
* Wed Jun 18 2008 maw@suse.de
- Update to version 2.23.3:
  + Migration to gio/gvfs
  + An initial set of default plugins
  + New command line option --new-instance to force creation of a
    new instance instead of reusing existing one
  + PNG metadata (XMP and color profile) support
  + Enable arrow keys to scroll the image if zoomed in
  + Miscellaneous improvements in thumbnailing code
  + Several metadata handling improvements
  + Use gtk-doc to document plugin API
  + Bugs fixed: bgo#528454, bgo#533041, bgo#532925, bgo#530102,
    bgo#531300, bgo#531809, bgo#343061, bgo#427053, bgo#466566,
    bgo#492017, bgo#517017, bgo#517821, bgo#523173, bgo#525618,
    bgo#526331, bgo#527798, bgo#522077, and bgo#523856
  + Updated translations.
* Tue Apr  8 2008 maw@suse.de
- Update to version 2.22.1:
  + Improved XMP metadata support
  + Keyboard navigation fixes
  + Fixed some memory leaks, compile time warnings, and critical
    warnings
  + Bugs fixed: bgo#427053, bgo#517017, and bgo#526331
  + Updated translations.
* Fri Mar 21 2008 vuntz@suse.de
- Add a gnome-desktop-devel buildrequires to fix the build.
* Fri Mar 14 2008 maw@suse.de
- Update to version 2.22.0:
  + Contextual menu in image view widget
  + Support for resetting the toolbar to its default layout
  + Performance improvements
  + Plugin API improvements
  + Bugs fixed: bgo#519028, bgo#519910, bgo#498989, bgo#506421,
    and #509079
  + Updated translations.
* Tue Mar  4 2008 maw@suse.de
- Update to version 2.21.92:
  + Bugs fixed: bgo#513958, bgo#500203, bgo#513827, and bgo#517450
  + Updated translations
- Drop eog-fast-image-switch-crash.patch.
* Tue Feb 19 2008 rodrigo@suse.de
- Update to version 2.21.90:
  * http://ftp.gnome.org/pub/GNOME/sources/eog/2.21/eog-2.21.90.news
- Filed patch upstream (bgo#517450)
* Tue Feb  5 2008 jpr@suse.de
- Add libexempi-devel to build requires (bnc #310430)
- Enable lcms support
- Enable python plugin support
* Fri Jan 25 2008 maw@suse.de
- Update to version 2.21.4:
  + Bugs (bugzilla.gnome.org) fixed: #487075, #491092, #496464,
    [#501073], #503637, #504093, #505576, #505811, #505949, #507068,
    [#509149], #458661, #491528, #491826, #494881, #496184, #499154,
    [#499156], #480975, #482752, #475124, #475645, #476313, #476919,
    [#477550], #479029, #479400, #479884, #481096, #481301, #482128,
    [#486057], #488344, #488808, #490065, and #481712
  + Fix ICC profiles implementation
  + Do not close a window while an image is being saved
  + More discrete toolbar in fullscreen mode
  + Added documentation for the toolbar editor
  + Misc. performance improvements
  + Misc. UI improvements, code improvements, leaks fixed, etc
  + Miscellaneous fixes in the UI
  + Support for resetting the toolbar to its default layout
  + Fixes for memory leaks and code optimizations
  + Improvements in plugin API
  + Improvements in the plugin system Python bindings
  + Code cleanups
  + Updated translations.
* Thu Oct 11 2007 sbrabec@suse.cz
- Removed bogus dependency on mDNSResponder.
* Mon Sep 17 2007 mauro@suse.de
- Update to version 2.20:
  * Complete rewrite of application core which means more stable,
    maintanable, faster image viewer for GNOME
  * New plugin system which allows developers to extend EOG's UI
    and behavior. Python support is available.
  * Editable application toolbar
  * New image collection pane with on-demand thumbnail loading,
    polished look, and continuous scrolling side buttons.
  * Side Pane to be extended by plugins
  * New image properties dialog which replaces the image info
    sidepane
  * Single instance D-Bus-based activation support
  * Revamped error/warning UI
  * "Open with" support to quickly open images on other applications
  * Mouse scrollwheel improvements: HIG compliancy and zoom factor
    setting
  * General UI polishing
  * Command line options for fullscreen, slideshow and image collection
    disabling
  * Display EXIF MakerNotes
  * XMP Support
- Patch eog-casts.patch is being removed since it's already applied upstream.
* Mon Sep 10 2007 mauro@suse.de
- Update to version 2.19.92:
  + New feature: New image collection pane layout with continuous scrolling
    side buttons
  + Bug fixes: #427046, #458663
  + Updated translations.
* Wed Aug 29 2007 maw@suse.de
- Update to version 2.19.91:
  * Features:
    + XMP support
    + Side pane can be expanded by plugins
    + Inhibit screensaver when running slideshow/fullscreen
    + Improved selection visual feedback in the image collection
    pane
  * Bugs (bugzilla.gnome.org) fixed: #470297, #311308, #467835,
    [#470416], #470686, #466681, #456451, #408591, #427806, #451101,
    [#453151], #455672, #455700, #459819, #460780, #462362, #462785,
    [#462971], #462973, #464709, #465060,and  #465628.
  * Updated translations
- Refresh eog-casts.patch.
* Tue Aug  7 2007 maw@suse.de
- Use %%fdupes
- Split off a -lang subpackage.
* Fri Aug  3 2007 mauro@suse.de
- Update to version 2.19.4
- Bugfixes for #449741, #453503, #435408, #453064, #452923, #452886,
  [#340831], #374582, #450590, #413211, #350809, #425613, #438242,
  [#440168].
* Sat Jul 14 2007 aj@suse.de
- It's really libwnck-devel.
* Wed Jul 11 2007 maw@suse.de
- Add explicit versions in Provides: and Obsoletes:
- Buildrequire libwnck-1-22-devel instead of libwnck-devel.
* Mon Jul  9 2007 maw@suse.de
- Update to version 2.19.3
- New -devel subpackage
- Various bug fixes.
* Mon Jun 18 2007 maw@suse.de
- Update to version 2.18.2, which has the following changes (bug
  numbers are for bugzilla.gnome.org):
- Calculate correctly the maximum printed image size on
  landscape page (Claudio Saavedra)
- Fix problem when possibly applying parallel image
  transformations (Felix Riemann) [#416257]
- Update icon cache when uninstalling icons (Brian Pepple) [#432439]
- Code cleanups (Felix Riemann) [#433127]
- Correctly set slideshow delay when being entered with
  the keyboard (Ryan Cumming)
- Update README and AUTHORS files (Claudio Saavedra) [#437691]
- Fix runtime critical warnings (Claudio Saavedra) [#430021]
- Manual fixes (Felix Riemann) [#431297]
- Updated translations: Yannig Marchegay (oc), Priit Laes (et)
* Thu Jun  7 2007 sbrabec@suse.cz
- Removed invalid desktop Category "Application" (#254654).
* Fri Apr 27 2007 sbrabec@suse.cz
- Do not call meinproc (#227624).
* Wed Apr 11 2007 maw@suse.de
- Update to version 2.18.1
- Build fixes (Lucas Rocha) [#398250]
- Code cleanups (Felix Riemann)
- Fixed critical warning when launching EOG without input
  URIs (Claudio Saavedra) [#417196]
- Updated translations: Laurent Dhima (sq),
  Luca Ferretti (it), Claudio Saavedra (es),
  Josep Puigdemont i Casamajó (ca), Ignacio Casa Quinteiro (gl),
  Inaki Larranaga Murgoitio (eu), Pema Geyleg (dz)
- Updated manual translations: Claudio Saavedra (es),
  Daniel Nylander (sv), Leonardo Ferreira Fontenelle (pt_BR)
* Fri Mar 30 2007 maw@suse.de
- Update to version 2.18.0.1
- b.g.o 417684, 414968, 390266, 399982, 414547, 357427.
* Thu Mar  8 2007 maw@suse.de
- Update to version 2.17.91
- Refresh some patches that didn't cleanly apply.
* Sat Mar  3 2007 dmueller@suse.de
- readd accidentally dropped exif dependency
* Tue Feb 27 2007 dmueller@suse.de
- reduce buildrequires
* Thu Jan  4 2007 sbrabec@suse.cz
- Prefix changed to /usr.
- Spec file cleanup.
* Fri Oct 27 2006 meissner@suse.de
- If we only have "short" space for an entry, only
  try to write a "short" in there, not a "long". #214690
* Fri Oct 13 2006 aj@suse.de
- Add gnome-doc-utils-devel to BuildRequires.
* Tue Oct  3 2006 jhargadon@suse.de
- update to version 2.16.1
- Fixed memory leaks
- Code cleanups
- Fixed critical warnings
- Make sure the correct image is displayed when reselecting the current image
  while loading another one
- Updated translations
* Wed Sep 13 2006 jhargadon@suse.de
- update to version 2.16.0.1
- Fix infinite loop on canvas destruction
- Updated translations
* Wed Aug 30 2006 jhargadon@suse.de
- update to version 2.15.92
- .desktop file small fix
- Fix error when loading images with ':' in their filenames
  from command line
- Fix critical warnings when opening remote images
- Make transparency color preferences work on full screen
  mode
- Updated translations
* Fri Aug 18 2006 jhargadon@suse.de
- update to version 2.15.91
- Small fixes on error dialog
- Fix memory leak on image transformation
- Fix typo on UI message
- Panning around the image with arrows on fullscreen mode
- Updated translations
* Wed Aug  2 2006 gekker@suse.de
- Update to version 2.15.90
- Avoid losing EXIF data when saving changed jpeg images (Felix Riemman)
  [#309219]
- Make transparent color selection work (Felix Riemman) [#347600].
- Fix crash when switching images with mouse wheel (Callum McKenzie) [#340827]
- Updated translations
- Respect desktop saving lockdown (Lucas Rocha) [#341862]
- Disable xscreensaver on fullscreen mode (#326369)
- UI redesign. Fixes bugs #148643 and #320542. (Lucas Rocha)
- Fix crash when setting window icon. Fixes bug #320245.
- More coherent fullscreen/slide show behavior. Fixes
  bug #317392. (Lucas Rocha)
- Use intuitive gnome-icon-theme icon for image viewer
  instead of EOG icon. Fixes bug #167087. (Lucas Rocha)
- Don't crash when removing images from a collection.
  Fixes bug #313003. (Lucas Rocha)
- Add image/svg+xml to the list of supported file types.
- Fix RGBA->RGB conversion when saving PNG images to JPEG.
  Fixes bug #314742. (Felix Riemann)
- Update "recent files" when viewing images. Fixes bug #316004.
  (Lucas Rocha)
- Fix crash when trying to view an image from recent list that
  doesn't exist anymore. Fixes bug #312448. (Lucas Rocha)
- Fix crash when adding new non-image files to a directory eog
  watches and when trying to view a PNG image with a JPEG extension.
  Fixes bugs #316808 and #311925. (Callum McKenzie)
* Thu Jun  1 2006 joeshaw@suse.de
- Add a patch to fix a crash when toggling very quickly between
  two images.  (bnc #180396)
* Sun Mar 26 2006 ro@suse.de
- remove scrollkeeper stuff if created on s390*
* Tue Feb 28 2006 sbrabec@suse.cz
- Use kdelibs3-doc in BuildRequires for meinproc (#153635#c14).
* Fri Feb 17 2006 sreeves@suse.de
- Update .desktop file (Name, GenericName, Comment, DocPath)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Nov 30 2005 gekker@suse.de
- Update to version 2.12.2
* Wed Oct  5 2005 sbrabec@suse.cz
- Fixed gcc cast warnings.
* Mon Sep  5 2005 sbrabec@suse.cz
- Updated to version 2.12.0.
* Mon Aug 22 2005 gekker@suse.de
- Update to version 2.11.92
* Tue Aug  2 2005 gekker@suse.de
- Update to version 2.11.90
* Thu Jul 21 2005 gekker@suse.de
- Update to version 2.11.0
* Fri Jun 17 2005 gekker@suse.de
- Update to 2.10.0 (GNOME 2.10).
* Thu Feb 24 2005 sbrabec@suse.cz
- Removed gconf makefile-uninstall-rule (#33114).
* Tue Jan  4 2005 gekker@suse.de
- Update to version 2.9.0
- Removed exif patch which is no longer needed
* Wed Oct 27 2004 mmj@suse.de
- Locale rename no to nb
* Wed Aug 25 2004 clahey@suse.de
- Cache eog help files and have eog show up in khelpcenter.
- Only apply libexif patch if suse_version > 910.
* Fri Jul 30 2004 meissner@suse.de
- Fixed to work with newer libexif version.
* Mon Apr 26 2004 sbrabec@suse.cz
- Updated to version 2.6.1 (GNOME 2.6).
* Tue Feb 24 2004 sbrabec@suse.cz
- Use gconftool-2 scriptlets correctly.
* Fri Feb 20 2004 sbrabec@suse.cz
- Fixed PreReq.
* Fri Feb 20 2004 sbrabec@suse.cz
- Package renamed to eog.
* Thu Feb 12 2004 hhetter@suse.de
- gconf schema (de-)installation in %%post and %%postun
* Sat Jan 10 2004 adrian@suse.de
- add %%run_ldconfig
* Mon Oct 27 2003 sbrabec@suse.cz
- Updated to version 2.4.1 (GNOME 2.4).
* Wed Sep 17 2003 adrian@suse.de
- Martin wished to get it in Viewer menu
* Tue Aug 19 2003 sbrabec@suse.cz
- Updated neededforbuild (rename of librsvg2, eel2).
* Mon Jul 14 2003 sbrabec@suse.cz
- GNOME prefix change to /opt/gnome.
* Fri Jul 11 2003 hhetter@suse.de
- %%_lib fixes
- %%files fixes
* Thu Jun 26 2003 sbrabec@suse.cz
- Updated to version 2.2.2.
- Updated neededforbuild.
- Use %%find_lang.
* Tue Jan 28 2003 hhetter@suse.de
- updated to 2.2.0
* Mon Jan 20 2003 ro@suse.de
- update to 1.1.4
- review filelist
* Thu Nov 28 2002 hhetter@suse.de
- updated to version 1.0.4 [GNOME 2.0.3]
* Mon Nov 11 2002 ro@suse.de
- changed neededforbuild <xf86 xdevel> to <x-devel-packages>
* Tue Oct 22 2002 hhetter@suse.de
- updated to stable version 1.0.3
- remove wrong docdir
- %%_lib fixes
- FHS fix
* Mon Sep 23 2002 sbrabec@suse.cz
- Added alsa to neededforbuild, because esound can depend on it.
* Tue Aug 20 2002 hhetter@suse.de
- added PreReq: filesystem
* Mon Aug 12 2002 ro@suse.de
- remove control-center from neededforbuild
* Tue Aug  6 2002 hhetter@suse.de
- updated to version 1.0.2
  * We don't crash anymore if the user doesn't have
  permissions to read
  a file - #85263
  * We do the right thing to destroy the window
  list on File/Exit -
  [#86469]
  * Components are installed in $(libexec)
  * The window is correctly sized upon startup,
  and you can shrink it
  again - #72352, #75713
  * No distorted view when resizing an empty window - #85927
  * DnD into an empty window doesn't open a new window.
  * New Bulgarian translation
  * Load control ui xml file correctly
  * New Albanian translation
- libexec filelist corrections
* Thu Jun 20 2002 hhetter@suse.de
- don't install schemas while make install
* Thu Jun 20 2002 hhetter@suse.de
- updated to version 1.0.1
- provide bonobo servers
* Fri Jun 14 2002 hhetter@suse.de
- filelist fix
* Thu Jun 13 2002 hhetter@suse.de
- supply schema file
* Tue Jun 11 2002 hhetter@suse.de
- updated to version 1.0.0
* Fri Jun  7 2002 hhetter@suse.de
- initial SuSE Release
